/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void errorMsg();
   void criticalMsg();

   QLineEdit *error_text;
   QLineEdit *critical_text;

   QErrorMessage *errorDialog = nullptr;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   QPushButton *err_pb = new QPushButton("Error");
   error_text = new QLineEdit();

   QPushButton *critical_pb = new QPushButton("Critical");
   critical_text = new QLineEdit();

   //
   QPushButton *close_pb = new QPushButton();
   close_pb->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(20);
   grid1->setVerticalSpacing(45);

   grid1->addWidget(err_pb, 0, 0);
   grid1->addWidget(error_text, 0, 1);

   grid1->addWidget(critical_pb, 1, 0);
   grid1->addWidget(critical_text, 1, 1);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(close_pb);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout1);

   connect(err_pb,      &QPushButton::clicked, this, &MainWindow::errorMsg);
   connect(critical_pb, &QPushButton::clicked, this, &MainWindow::criticalMsg);

   connect(close_pb,    &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::errorMsg()
{
   if (errorDialog == nullptr) {
      errorDialog = new QErrorMessage(this);
   }

   errorDialog->showMessage(
      "If the checkbox remains checked, this message box will be displayed again. \n"
      "If unchecked, this message box will not appear again for the same error message.");

   error_text->setText("Message displayed");
}

void MainWindow::criticalMsg()
{
   QMessageBox::StandardButton reply;

   reply = QMessageBox::critical(this, "Critical",
      "Body of a critical message. Click one of the buttons, X icon, or press Esc",
      QMessageBox::Abort | QMessageBox::Retry | QMessageBox::Ignore);

   if (reply == QMessageBox::Abort) {
      critical_text->setText("Abort");

   } else if (reply == QMessageBox::Retry) {
      critical_text->setText("Retry");

   } else  {
      critical_text->setText("Ignore");
   }
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
